CrossmintContractMetadataService class

Fetches and validates on-chain contract metadata (ERC-7572) for verifiable credential collections.

Constructors

CrossmintContractMetadataService({required CrossmintNftService nftService, CrossmintVcDocumentLoader? documentLoader, CrossmintVcConfig? config, Client? httpClient})

Properties

documentLoader CrossmintVcDocumentLoader?
final
hashCode int
The hash code for this object.
no setterinherited
nftService CrossmintNftService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCollectionMetadata(String contractAddress, CrossmintVcChain chain, List<CrossmintVcNft> nfts) Future<CrossmintCredentialsCollection?>
Fetches contract metadata and validates it as a VC collection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited