CrossmintCredentialDecryptRequest class final

Constructors

CrossmintCredentialDecryptRequest({String? credentialId, String? locator, CrossmintJsonMap raw = const <String, Object?>{}})
const

Properties

credentialId String?
final
hashCode int
The hash code for this object.
no setterinherited
locator String?
final
raw CrossmintJsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited