CrossmintCredentialRecord class final

Constructors

CrossmintCredentialRecord({required String id, CrossmintJsonMap raw = const <String, Object?>{}})
const

Properties

encryptedCredential CrossmintJsonMap?
no setter
encryptedVerifiableCredential CrossmintEncryptedVerifiableCredential?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
final
raw CrossmintJsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unencryptedCredential CrossmintJsonMap?
no setter
verifiableCredential CrossmintVerifiableCredential?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited