CrossmintCredentialRetrievalProcedure class final

Constructors

CrossmintCredentialRetrievalProcedure({required bool endpointCondition(String endpoint), required Future<CrossmintCredentialType> procedure({required String locator, required String retrievalPath})})
const

Properties

endpointCondition bool Function(String endpoint)
final
hashCode int
The hash code for this object.
no setterinherited
procedure Future<CrossmintCredentialType> Function({required String locator, required String retrievalPath})
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited