CrossmintDecrypt class final

Constructors

CrossmintDecrypt(String userAddress, CrossmintWalletChallengeSigner signCallback, {WalletAuthService? authService})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signCallback → CrossmintWalletChallengeSigner
final
userAddress → String
final

Methods

decrypt(CrossmintEncryptedVerifiableCredential credential) → Future<CrossmintVerifiableCredential>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited