CrossmintDeviceSignerDescriptor class final
Constructors
- CrossmintDeviceSignerDescriptor({required String publicKeyX, required String publicKeyY, required String locator, String? name})
-
const
- CrossmintDeviceSignerDescriptor.fromJson(CrossmintJsonMap json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- locator → String
-
final
- name → String?
-
final
- publicKeyX → String
-
final
- publicKeyY → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → CrossmintJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override