CrossmintExportSignerBridgeClient class final
Constructors
- CrossmintExportSignerBridgeClient({required CrossmintExportSignerBridge bridge, Duration defaultTimeout = const Duration(seconds: 30)})
-
const
Properties
- defaultTimeout → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exportSigner(
{required String jwt, required String apiKey, required CrossmintSignerKeyType keyType, required CrossmintExportSignerEncoding encoding}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited