CrossmintSignerConfig class sealed

Constructors

CrossmintSignerConfig.fromJson(CrossmintJsonMap json)
Deserializes a signer config from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() CrossmintJsonMap
Serializes this config to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited