CrossmintUser class final

Constructors

CrossmintUser({required String id, String? email, CrossmintJsonMap raw = const <String, Object?>{}})
const
CrossmintUser.fromJson(CrossmintJsonMap json)
factory

Properties

email String?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
raw CrossmintJsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() CrossmintJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override