CrossmintVcConfig class
Configuration for VC on-chain services: RPC endpoints, IPFS gateways, and timeouts.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ipfsGateways
→ List<
String> -
no setter
- ipfsTimeout → Duration
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRpcEndpoint(
CrossmintVcChain chain) → String - Returns the JSON-RPC endpoint for the given chain.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaults → CrossmintVcConfig
-
final