CrossmintWallet class final

Constructors

CrossmintWallet({required String id, String? chain, String? address, String? owner, CrossmintJsonMap raw = const <String, Object?>{}})
const
CrossmintWallet.fromJson(CrossmintJsonMap json)
factory

Properties

address String?
final
chain String?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
owner String?
final
raw CrossmintJsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() CrossmintJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override