CrossmintWalletApproveRequest class final

Constructors

CrossmintWalletApproveRequest({String? transactionId, String? signatureId, List<CrossmintJsonMap> approvals = const <CrossmintJsonMap>[], CrossmintJsonMap raw = const <String, Object?>{}})
const
CrossmintWalletApproveRequest.signature({required String signatureId, List<CrossmintJsonMap> approvals = const <CrossmintJsonMap>[], CrossmintJsonMap raw = const <String, Object?>{}})
const
CrossmintWalletApproveRequest.transaction({required String transactionId, List<CrossmintJsonMap> approvals = const <CrossmintJsonMap>[], CrossmintJsonMap raw = const <String, Object?>{}})
const

Properties

approvals List<CrossmintJsonMap>
final
hashCode int
The hash code for this object.
no setterinherited
hasSingleApprovalTarget bool
no setter
isSignatureApproval bool
no setter
isTransactionApproval bool
no setter
normalizedSignatureId String?
no setter
normalizedTransactionId String?
no setter
raw CrossmintJsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureId String?
final
transactionId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited