CrossmintWalletAuthChallenge class final

Challenge returned by CrossmintAuthClient.signInWithWallet that must be signed by the user's external wallet (MetaMask, Phantom, etc.).

Constructors

CrossmintWalletAuthChallenge({required String message, String? nonce, CrossmintJsonMap raw = const <String, Object?>{}})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
message → String
The message the wallet must sign.
final
nonce → String?
Replay-protection nonce.
final
raw → CrossmintJsonMap
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override