CrossmintWalletBalanceSnapshot class final

Constructors

CrossmintWalletBalanceSnapshot({required String walletId, List<CrossmintJsonMap> items = const <CrossmintJsonMap>[], CrossmintJsonMap raw = const <String, Object?>{}})
const
CrossmintWalletBalanceSnapshot.fromJson(CrossmintJsonMap json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
items List<CrossmintJsonMap>
final
raw CrossmintJsonMap
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override