CrossmintWalletNftPage class final
Constructors
-
CrossmintWalletNftPage({List<
CrossmintNftRecord> items = const <CrossmintNftRecord>[], CrossmintJsonMap raw = const <String, Object?>{}}) -
const
- CrossmintWalletNftPage.fromJson(CrossmintJsonMap json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
→ List<
CrossmintNftRecord> -
final
- raw → CrossmintJsonMap
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override