CrossmintWalletSigner class final

Constructors

CrossmintWalletSigner({required String type, required String locator, String? status, String? address, CrossmintJsonMap raw = const <String, Object?>{}})
const
CrossmintWalletSigner.fromJson(CrossmintJsonMap json)
factory

Properties

address → String?
final
hashCode → int
The hash code for this object.
no setteroverride
locator → String
final
raw → CrossmintJsonMap
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → CrossmintJsonMap
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override