HiddenSignerBridgeState class final

Constructors

HiddenSignerBridgeState({required HiddenSignerBridgePhase phase, Object? lastError, int requestCount = 0, int handshakeGeneration = 0})
const
HiddenSignerBridgeState.idle()
const

Properties

handshakeGeneration int
final
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
lastError Object?
final
phase HiddenSignerBridgePhase
final
requestCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({HiddenSignerBridgePhase? phase, Object? lastError, bool preserveLastError = true, int? requestCount, int? handshakeGeneration}) HiddenSignerBridgeState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited