event property
Hosted-page event associated with this diagnostic, if any (e.g. the original postMessage event name that failed to parse).
Implementation
final String? event;
Hosted-page event associated with this diagnostic, if any (e.g. the original postMessage event name that failed to parse).
final String? event;