orderId property

String orderId
final

Identifier of an order previously created via the Crossmint orders API (server-side) or a prior embedded-checkout session. The hosted checkout resumes this order instead of creating a new one.

Implementation

final String orderId;