recipient property
Optional recipient for the order. When omitted, the hosted checkout collects recipient details from the buyer.
Implementation
final CrossmintCheckoutRecipient? recipient;
Optional recipient for the order. When omitted, the hosted checkout collects recipient details from the buyer.
final CrossmintCheckoutRecipient? recipient;