receiptEmail property
Email to receive the order receipt. Leave null to use the recipient email (for CrossmintCheckoutEmailRecipient) or rely on the user entering an email inside the hosted page.
Implementation
final String? receiptEmail;
Email to receive the order receipt. Leave null to use the recipient email (for CrossmintCheckoutEmailRecipient) or rely on the user entering an email inside the hosted page.
final String? receiptEmail;