CrossmintCheckoutTokenLineItem class final
Line item that purchases a specific token. Usually built via CrossmintCheckoutLineItem.token.
- Inheritance
-
- Object
- CrossmintCheckoutLineItem
- CrossmintCheckoutTokenLineItem
Constructors
Properties
-
additionalFields
→ Map<
String, Object?> -
Forward-compatibility escape hatch — extra keys appended to the JSON
payload.
final
-
callData
→ Map<
String, Object?> ? -
Optional call data passed to the on-chain purchase transaction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenLocator → String
-
Token locator (e.g.
"crossmint:<token-id>").final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited