CrossmintCheckoutTransactionSuccess class final
Returned when the payer successfully signed and broadcast a transaction.
- Inheritance
-
- Object
- CrossmintCheckoutTransactionResult
- CrossmintCheckoutTransactionSuccess
Constructors
- CrossmintCheckoutTransactionSuccess({required String txId})
-
Creates a success result.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited