error property
String?
get
error
Localized error message from the last failed operation, or null if
the flow is in a clean state.
Implementation
String? get error => _error;
Localized error message from the last failed operation, or null if
the flow is in a clean state.
String? get error => _error;