CrossmintIdentityVerificationErrorReason enum

Why verification could not run or continue.

Inheritance
  • Object
  • Enum
  • CrossmintIdentityVerificationErrorReason
Available extensions

Values

widgetUnavailable → const CrossmintIdentityVerificationErrorReason
const CrossmintIdentityVerificationErrorReason('widget-unavailable')
invalidConfiguration → const CrossmintIdentityVerificationErrorReason
const CrossmintIdentityVerificationErrorReason('invalid-configuration')
invalidCredentials → const CrossmintIdentityVerificationErrorReason
const CrossmintIdentityVerificationErrorReason('invalid-credentials')
providerError → const CrossmintIdentityVerificationErrorReason
const CrossmintIdentityVerificationErrorReason('provider-error')
unknown → const CrossmintIdentityVerificationErrorReason
const CrossmintIdentityVerificationErrorReason('unknown')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireValue String
The value as it appears on the wire.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CrossmintIdentityVerificationErrorReason>
A constant List of the values in this enum, in order of their declaration.