CrossmintThemeData class

Constructors

CrossmintThemeData({Color? accentColor, Color? backgroundColor, Color? textPrimaryColor, Color? textSecondaryColor, Color? borderColor, Color? inputBackgroundColor, Color? dangerColor, Color? linkColor, double? borderRadius})
const

Properties

accentColor Color?
Green accent for primary buttons and badges. RN: cm-accent.
final
backgroundColor Color?
Dialog/modal background. RN: cm-background-primary.
final
borderColor Color?
Border color for inputs and contact containers. RN: cm-border.
final
borderRadius double?
Border radius for containers and inputs (not pill buttons).
final
dangerColor Color?
Error/danger color. RN: cm-danger.
final
hashCode int
The hash code for this object.
no setterinherited
inputBackgroundColor Color?
Input field background. RN: cm-muted-primary.
final
linkColor Color?
Link color. RN: cm-link.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textPrimaryColor Color?
Primary text. RN: cm-text-primary.
final
textSecondaryColor Color?
Secondary/muted text. RN: cm-text-secondary.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveAccent(BuildContext context) Color
resolveBackground(BuildContext context) Color
resolveBorder(BuildContext context) Color
resolveBorderRadius() double
resolveDanger(BuildContext context) Color
resolveInputBackground(BuildContext context) Color
resolveTextPrimary(BuildContext context) Color
resolveTextSecondary(BuildContext context) Color
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const CrossmintThemeData