onError property
Called when the OAuth flow throws. Receives the underlying exception so consumers can surface a localized error message.
Implementation
final void Function(Object error)? onError;
Called when the OAuth flow throws. Receives the underlying exception so consumers can surface a localized error message.
final void Function(Object error)? onError;