CrossmintWalletActionsViewModel class final

Properties

client CrossmintClient?
no setter
hasDependencies bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
walletController CrossmintWalletController?
no setter

Methods

clearWallet() Future<void>
ensureWalletLoaded() Future<void>
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshWallet() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited