CrossmintWalletContextData class final

Constructors

CrossmintWalletContextData({required CrossmintWalletUiState state, required CrossmintWalletSessionViewModel session, required CrossmintWalletActionsViewModel actions, required CrossmintWalletOtpViewModel otp, CrossmintClient? client, CrossmintAuthClient? auth, CrossmintWalletController? walletController})
const

Properties

actions CrossmintWalletActionsViewModel
final
auth CrossmintAuthClient?
final
client CrossmintClient?
final
hashCode int
The hash code for this object.
no setterinherited
otp CrossmintWalletOtpViewModel
final
requireAuth CrossmintAuthClient
no setter
requireClient CrossmintClient
no setter
requireWalletController CrossmintWalletController
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session CrossmintWalletSessionViewModel
final
state CrossmintWalletUiState
final
walletController CrossmintWalletController?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited