CrossmintWalletOtpViewModel class final
- Inheritance
-
- Object
- ChangeNotifier
- CrossmintWalletOtpViewModel
Constructors
Properties
- controller → CrossmintWalletOtpController?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- needsOtp → bool
-
no setter
- pendingChallenge → CrossmintOtpChallenge?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
attachController(
CrossmintWalletOtpController? controller) → void -
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
reject(
[Object? error]) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
sendOtp(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
verifyOtp(
String otp) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited