CrossmintWalletSessionViewModel class final

Inheritance

Properties

client CrossmintClient?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CrossmintWalletUiState
no setter
walletController CrossmintWalletController?
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attachDependencies({required CrossmintClient client, required CrossmintWalletController walletController, required bool autoLoadWallet}) → void
clearDependencies() → void
clearWallet() Future<void>
dispose() → void
Discards any resources used by the object.
override
ensureWalletLoaded() Future<void>
failInitialization(Object error) → void
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refreshWallet() Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
startInitializing() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited