buildCheckoutConnectWalletFailed function

Map<String, Object?> buildCheckoutConnectWalletFailed(
  1. String error
)

Builds the reply sent back when wallet connection fails. error is surfaced to the user inside the hosted page.

Implementation

Map<String, Object?> buildCheckoutConnectWalletFailed(String error) {
  return <String, Object?>{
    'event': 'crypto:connect-wallet.failed',
    'data': <String, Object?>{'error': error},
  };
}