CrossmintPhoneSignerConfig class final
- Inheritance
-
- Object
- CrossmintSignerConfig
- CrossmintPhoneSignerConfig
Constructors
- CrossmintPhoneSignerConfig({String? phone, String? locator, CrossmintOtpDeliveryChannel? channel})
-
const
Properties
- channel → CrossmintOtpDeliveryChannel?
-
Requested OTP delivery channel. Null means the service default (SMS).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- locator → String?
-
final
- phone → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → CrossmintJsonMap -
Serializes this config to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override