CrossmintSignerBridgePublicKey class final
Constructors
- CrossmintSignerBridgePublicKey({required String bytes, required CrossmintSignerEncoding encoding, required CrossmintSignerKeyType keyType})
-
const
Properties
- bytes → String
-
final
- encoding → CrossmintSignerEncoding
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyType → CrossmintSignerKeyType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited