CrossmintStellarContractCallRequest class final

Inheritance

Constructors

CrossmintStellarContractCallRequest({required String contractId, required String method, required CrossmintJsonMap args, String? memo, String? signerLocator, CrossmintJsonMap raw = const <String, Object?>{}})
const

Properties

args CrossmintJsonMap
final
contractId String
final
hashCode int
The hash code for this object.
no setterinherited
memo String?
final
method String
final
raw CrossmintJsonMap
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signerLocator String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited