CrossmintWalletLifecycleCallbacks class final
Optional lifecycle hooks invoked at key points in the wallet controller.
Useful for showing blocking UI (e.g. a spinner during wallet creation) or pre-authorizing a transaction with the user via native UI.
Constructors
-
CrossmintWalletLifecycleCallbacks({Future<
void> onWalletCreationStart()?, Future<void> onTransactionStart()?}) -
Creates a lifecycle callback bundle.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onTransactionStart
→ Future<
void> Function()? -
Called immediately before the controller issues a create-transaction API
call. Await to block until your UI is ready.
final
-
onWalletCreationStart
→ Future<
void> Function()? -
Called immediately before the controller issues a
createWalletAPI call. Await the returned future to block the operation until your UI is ready.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited