SoftwareDeviceSignerKeyStorage class final
Software-backed device signer key storage for dev/test environments.
This implementation generates P-256 keys in-memory, matching the official
Crossmint RN SDK's SoftwareDeviceSignerKeyStorage used in Expo Go and
development builds where native hardware-backed storage is unavailable.
Do not use in production. Keys are stored in memory and lost when the app process terminates.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteKey(
String address) → Future< void> -
override
-
deletePendingKey(
String publicKeyBase64) → Future< void> -
override
-
generateKey(
{String? address, CrossmintBiometricPolicy biometricPolicy = CrossmintBiometricPolicy.none}) → Future< String> -
override
-
getDeviceName(
) → Future< String?> -
override
-
getKey(
String address) → Future< String?> -
override
-
hasKey(
String publicKeyBase64) → Future< bool> -
override
-
isAvailable(
) → Future< bool> -
override
-
mapAddressToKey(
String address, String publicKeyBase64) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signMessage(
String address, String message) → Future< Map< String, Object?> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited