CrossmintCheckoutAppearance class final
UI customization for the hosted checkout page.
Supports three levels of customization:
Constructors
Properties
-
fonts
→ List<
Map< ?String, String> > -
Custom font definitions
(e.g.
[{'cssSrc': 'https://fonts.googleapis.com/...'}]).final - hashCode → int
-
The hash code for this object.
no setterinherited
-
rules
→ Map<
String, Object?> ? -
CSS rules for specific checkout elements
(e.g.
{'.Input': {'borderColor': '#CBD5E1'}}).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variables
→ Map<
String, Object?> ? -
CSS custom properties for theming (e.g.
{'colorPrimary': '#0F172A'}).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes the appearance configuration to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited