CrossmintCheckoutDefaultMethod enum
Typed default payment method — which tab/method the hosted checkout opens on.
Values
- fiat → const CrossmintCheckoutDefaultMethod
-
Open the checkout on fiat (credit card / Apple Pay / Google Pay).
const CrossmintCheckoutDefaultMethod('fiat') - crypto → const CrossmintCheckoutDefaultMethod
-
Open the checkout on crypto (on-chain payment).
const CrossmintCheckoutDefaultMethod('crypto')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
Wire-level string value (
"fiat"or"crypto") sent to the Crossmint-hosted page.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CrossmintCheckoutDefaultMethod> - A constant List of the values in this enum, in order of their declaration.