CrossmintCheckoutEmailRecipient class final
Email-based recipient — mints into a Crossmint-managed wallet associated with the email address. Pair with physicalAddress when the line items include physical fulfillment.
- Inheritance
-
- Object
- CrossmintCheckoutRecipient
- CrossmintCheckoutEmailRecipient
Constructors
- CrossmintCheckoutEmailRecipient({required String email, CrossmintCheckoutPhysicalAddress? physicalAddress})
-
Creates an email recipient.
const
Properties
- email → String
-
Recipient email address.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- physicalAddress → CrossmintCheckoutPhysicalAddress?
-
Optional shipping address for physical line items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited