CrossmintCheckoutProductLineItem class final

Line item that purchases a product (often physical or hybrid). Usually built via CrossmintCheckoutLineItem.product.

Inheritance

Constructors

CrossmintCheckoutProductLineItem({required String productLocator, Map<String, Object?> additionalFields = const <String, Object?>{}})
Creates a product line item.
const

Properties

additionalFields Map<String, Object?>
Forward-compatibility escape hatch.
final
hashCode int
The hash code for this object.
no setterinherited
productLocator String
Product locator registered with Crossmint.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited