CrossmintCheckoutTokenExecutionLineItem class final
Line item that executes a token purchase with arbitrary execution parameters. Usually built via CrossmintCheckoutLineItem.tokenWithExecutionParameters.
- Inheritance
-
- Object
- CrossmintCheckoutLineItem
- CrossmintCheckoutTokenExecutionLineItem
Constructors
Properties
-
additionalFields
→ Map<
String, Object?> -
Forward-compatibility escape hatch.
final
-
executionParameters
→ Map<
String, Object?> -
Structured execution parameters — shape depends on the token contract.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenLocator → String
-
Token locator.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited