CrossmintCheckoutTransactionFailure class final

Returned when the payer could not complete the transaction. The hosted page surfaces errorMessage to the user.

Inheritance

Constructors

CrossmintCheckoutTransactionFailure({required String errorMessage})
Creates a failure result.
const

Properties

errorMessage String
Short, user-facing failure description.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited