CrossmintIdentityVerificationHandling enum
Who renders the identity verification step when an order requires it.
Values
- external → const CrossmintIdentityVerificationHandling
-
Checkout does not render verification. You mount
CrossmintIdentityVerificationyourself from the controller'sidentityVerificationCredentials, or the buyer cannot finish.const CrossmintIdentityVerificationHandling('external')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
The value as it appears on the wire.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CrossmintIdentityVerificationHandling> - A constant List of the values in this enum, in order of their declaration.