CrossmintWalletUiState class final
Constructors
- CrossmintWalletUiState({required bool isInitializing, required bool isLoadingWallet, required CrossmintAuthState authState, required CrossmintWalletStatus walletStatus, required CrossmintWallet? currentWallet, required CrossmintOtpChallenge? pendingOtpChallenge, Object? initializationError, Object? walletError})
-
const
- CrossmintWalletUiState.initial()
-
factory
Properties
- authErrorMessage → String?
-
no setter
- authState → CrossmintAuthState
-
final
- currentWallet → CrossmintWallet?
-
final
- error → Object?
-
no setter
- errorMessage → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWallet → bool
-
no setter
- initializationError → Object?
-
final
- isAuthenticated → bool
-
no setter
- isInitializing → bool
-
final
- isLoadingWallet → bool
-
final
- isLoggedOut → bool
-
no setter
- needsOtp → bool
-
no setter
- pendingOtpChallenge → CrossmintOtpChallenge?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → CrossmintAuthenticatedUser?
-
no setter
- walletError → Object?
-
final
- walletStatus → CrossmintWalletStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited